@@ -27,10 +27,10 @@ class PartDataEndpoint(Resource):
 
         """
         part_data = {
-            "timestamp": 1516193959559,
-            "part_id": "Part1234",
+            "identifiedTime": 1516193959559,
+            "partId": "Part1234",
             "source": "Camera_Control_PC_Garret",
-            "part_data": [
+            "partData": [
                 {
                     "key": "steel_grade",
                     "value": "Grade01"
@@ -42,23 +42,10 @@ class PartDataEndpoint(Resource):
                 {
                     "key": "rolling_schedule",
                     "value": "Schedule1"
-                },
-                {
-                    "key": "analysis",
-                    "value": [
-                        {
-                            "key": "C",
-                            "value": "0.2"
-                        },
-                        {
-                            "key": "Mn",
-                            "value": "0.02"
-                        }
-                    ]
                 }
             ]
         }
-        return {'data': part_data}, 200  # return data and 200 OK code
+        return part_data, 200  # return data and 200 OK code
 
     def post(self):
         """
@@ -72,7 +59,8 @@ class PartDataEndpoint(Resource):
         """
         json_data = request.json
         # TODO validate json data
-        return {'data': json_data}, 200  # return data with 200 OK
+        # return data with 201 created success code
+        return json_data, 201
 
 
 class ImageMetaDataEndpoint(Resource):
@@ -123,7 +111,7 @@ class ImageMetaDataEndpoint(Resource):
                 }
             ]
         }
-        return {'data': image_meta_data}, 200  # return data and 200 OK code
+        return image_meta_data, 200  # return data and 200 OK code
 
     def post(self):
         """
@@ -137,7 +125,8 @@ class ImageMetaDataEndpoint(Resource):
         """
         json_data = request.json
         # TODO validate json data
-        return {'data': json_data}, 200  # return data with 200 OK
+        # return data with 201 created success code
+        return json_data, 201
 
 
 class ImageAnalysisDataEndpoint(Resource):
@@ -214,7 +203,7 @@ class ImageAnalysisDataEndpoint(Resource):
             ]
         }
         # return data and 200 OK code
-        return {'data': image_analysis_data}, 200
+        return image_analysis_data, 200
 
     def post(self):
         """
@@ -229,7 +218,8 @@ class ImageAnalysisDataEndpoint(Resource):
         json_data = request.json
         print(json_data)
         # TODO validate json data
-        return {'data': json_data}, 200  # return data with 200 OK
+        # return data with 201 created success code
+        return json_data, 201
 
 
 def create_app(test_config=None):
@@ -285,9 +275,12 @@ def create_app(test_config=None):
         """
         return page
 
-    api.add_resource(PartDataEndpoint, '/api/part_data')
-    api.add_resource(ImageMetaDataEndpoint, '/api/image_meta_data')
-    api.add_resource(ImageAnalysisDataEndpoint, '/api/image_analysis_data')
+    api.add_resource(
+        PartDataEndpoint, '/imath-rest-backend/part')
+    api.add_resource(
+        ImageMetaDataEndpoint, '/imath-rest-backend/image_meta_data')
+    api.add_resource(
+        ImageAnalysisDataEndpoint, '/imath-rest-backend/image_analysis_data')
 
     return app, api
 
